==> mysql-8.4_8.4.6.orig.tar.gz: mysql-8.4.6/storage/ndb/include/util/NdbTap.hpp <==
/*
   Copyright (c) 2008, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef NDB_TAP_HPP
#define NDB_TAP_HPP

#include "unittest/mytap/tap.h"
#include "util/require.h"

#define OK(b) require(b)

#define TAPTEST(name)                     \
  int name##_test();                      \
  int main(int argc, const char **argv) { \
    (void)argc;                           \
    (void)argv; /* unused args */         \
    plan(1);                              \
    ok(name##_test(), #name);             \
    return exit_status();                 \
  }                                       \
  int name##_test()

#endif

==> mysql-9.6.0.tar.gz: mysql-9.6.0/storage/ndb/include/util/NdbTap.hpp <==
/*
   Copyright (c) 2008, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef NDB_TAP_HPP
#define NDB_TAP_HPP

#include "unittest/mytap/tap.h"
#include "util/require.h"

#define OK(b) require(b)

#define TAPTEST(name)                     \
  static int name##_test();               \
  int main(int argc, const char **argv) { \
    (void)argc;                           \
    (void)argv; /* unused args */         \
    plan(1);                              \
    ok(name##_test(), #name);             \
    return exit_status();                 \
  }                                       \
  int name##_test()

#endif
